@@ -32,7 +32,7 @@
 /** @file STK_ISvd.h
  *  @brief In this file we define the interface class ISvd.
  **/
- 
+
 #ifndef STK_ISVD_H
 #define STK_ISVD_H
 
@@ -46,16 +46,16 @@ namespace STK
 {
 /** @ingroup Algebra
  *  @brief Compute the Singular Value Decomposition of an array.
- * 
+ *
  *  The method take as:
  *  - input: A matrix A(nrow,ncol)
  *  - output:
  *    -# U Array (nrow,ncolU).
  *    -# D Vector (ncol)
  *    -# V Array (ncol,ncol).
- *  and perform the decomposition: 
+ *  and perform the decomposition:
  *  - A = UDV'
- *  U can have more cols than A,
+ *  U can have more columns than A,
  *  and it is possible to compute some (all) vectors of Ker(A).
  **/
 template<class Derived>
@@ -65,34 +65,35 @@ class ISvd: public IRunnerBase, public IRecursiveTemplate<Derived>
     typedef typename hidden::AlgebraTraits<Derived>::ArrayU ArrayU;
     typedef typename hidden::AlgebraTraits<Derived>::ArrayD ArrayD;
     typedef typename hidden::AlgebraTraits<Derived>::ArrayV ArrayV;
-    typedef TransposeOperator<ArrayV> ArrayVT;
+    typedef typename ArrayU::Type Type;
+
     /** Default constructor
      *  @param A the matrix to decompose.
      *  @param ref if true, U_ is a reference of A.
-     *  @param withU if @c true save the left housolder transforms in @c U_.
-     *  @param withV if @c true save the right housolder transforms in @c V_.
+     *  @param withU if @c true save the left Householder transforms in @c U_.
+     *  @param withV if @c true save the right Householder transforms in @c V_.
      **/
     inline ISvd( ArrayU const& A, bool ref, bool withU = true, bool withV = true)
-               : U_(A, ref), V_(), VT_(V_), D_()
-               , withU_(withU), withV_(withV), norm_(0), rank_(0)
+               : U_(A, ref), V_(), D_()
+               , withU_(withU), withV_(withV), norm_(0), rank_(0), trace_(0), det_(0)
     {}
     /** constructor with other kind of array/expression
      *  @param A the matrix/expression to decompose.
-     *  @param withU if @c true save the left housolder transforms in @c U_.
-     *  @param withV if @c true save the right housolder transforms in @c V_.
+     *  @param withU if @c true save the left Householder transforms in @c U_.
+     *  @param withV if @c true save the right Householder transforms in @c V_.
      */
     template<class OtherDerived>
     inline ISvd( ArrayBase<OtherDerived> const& A, bool withU = true, bool withV = true)
-               : U_(A), V_(), VT_(V_), D_()
-               , withU_(withU), withV_(withV), norm_(0), rank_(0)
+               : U_(A), V_(), D_()
+               , withU_(withU), withV_(withV), norm_(0), rank_(0), trace_(0), det_(0)
     {}
     /** Copy Constructor
      *  @param S the Svd to copy
      **/
     inline ISvd( ISvd const& S)
-        : U_(S.U_, S.U_.isRef()), V_(S.V_), VT_(V_), D_(S.D_)
-        , withU_(S.withU_), withV_(S.withV_)
-        , norm_(S.norm_), rank_(S.rank_)
+               : U_(S.U_, S.U_.isRef()), V_(S.V_), D_(S.D_)
+               , withU_(S.withU_), withV_(S.withV_)
+               , norm_(S.norm_), rank_(S.rank_), trace_(S.trace_), det_(S.det_)
     {}
     /** destructor. */
     inline virtual ~ISvd() {}
@@ -101,9 +102,9 @@ class ISvd: public IRunnerBase, public IRecursiveTemplate<Derived>
      **/
     ISvd& operator=(const ISvd &S)
     {
-      U_ =S.U_; V_ = S.V_;  D_ = S.D_;
+      U_ = S.U_; V_ = S.V_;  D_ = S.D_;
       withU_ =  S.withU_; withV_ = S.withV_;
-      norm_ = S.norm_; rank_ = S.rank_;
+      norm_ = S.norm_; rank_ = S.rank_; trace_ = S.trace_; det_ = S.det_;
       return *this;
     }
     /** Finalize any operations that have to be done after the computation
@@ -111,16 +112,100 @@ class ISvd: public IRunnerBase, public IRecursiveTemplate<Derived>
      **/
     virtual void finalize()
     {
-      // Compute the true max norm
-      norm_ = D_.front();
-      // Compute the rank
-      rank_ = 0;
-      for (int i=D_.begin(); i<D_.end(); i++)
-        if (norm_+D_[i] != norm_) { rank_++;}
-        else break;
+      // compute sign and trace
+      trace_ = 0.;
+      int s = 1;
+      for (int i=D_.begin(); i< D_.end(); ++i )
+      {
+        Type value = D_[i];
+        s *= sign(value);
+        trace_ += value;
+      }
+
+      // compute norm_ (2-norm) and determinant
+      norm_ = D_.maxElt();
+      det_  = 0;
+      if (D_.abs().minElt() > 0)
+      { det_ = s * std::exp(D_.abs().log().sum());}
+
+      // compute norm_ rank_
+      rank_ = D_.size(); // full rank
+      Type tol = norm_ * Arithmetic<Type>::epsilon();
+      for (int i=D_.begin(); i< D_.end(); ++i )
+      { if (std::abs(D_[i]) < tol) { rank_--;}}
 
     }
+
   public:
+    // getters
+    /** @return the product of the singular values*/
+    inline Type det() const { return det_;}
+    /** @return the sum of the singular values*/
+    inline Type trace()  const { return trace_;}
+    /** @return the norm of the matrix */
+    inline Type norm()  const { return norm_;}
+    /** @return the rank of the matrix */
+    inline int rank()  const { return rank_;}
+    /** @return U */
+    inline ArrayU const& U() const { return U_;}
+    /** @return  V */
+    inline ArrayV const& V() const { return V_;}
+    /** @return D */
+    inline ArrayD const&  D() const { return D_;}
+
+    /** implement the run method */
+    virtual bool run()
+    {
+      if (U_.empty()) { return true;}
+      // compute Svd decomposition
+      if (!this->asDerived().runImpl()) return false;
+      finalize();
+      return true;
+    }
+    /** Set a new data set to ISvd class
+     *  @note Take care that if U_ was previously a reference, it cannot be modified.
+     *  @warning A^{-1}A give identity matrix if m<=n, and AA^{-1} give identity matrix
+     *  if n<=m
+     *
+     *  @param A is the matrix to decompose.
+     *  @param withU if @c true, we save the left Housolder transforms in U_.
+     *  @param withV if @c true, we save the right Housolder transforms in V_.
+     **/
+    template<class OtherArray>
+    void setData( OtherArray const& A, bool withU = true, bool withV = true)
+    {
+      U_ = A;           // Copy A in U_
+      withU_ = withU;   // copy withU_ value
+      withV_ = withV;   // copy withV_ value
+      V_.resize(0,0), D_.resize(0);
+    }
+    /** Compute the generalized inverse of the matrix and put the result in res.
+     *  @param res array with the result
+     *  @return the result
+     */
+    template<class OtherArray>
+    OtherArray& ginv(OtherArray& res) const;
+
+  protected:
+    /// U_ matrix
+    ArrayU U_;
+    /// V_ matrix
+    ArrayV V_;
+    /// Diagonal array of the singular values
+    ArrayD D_;
+    /// Compute U_ ?
+    bool withU_;
+    /// Compute V_ ?
+    bool withV_;
+    /** trace norm */
+    Type norm_;
+    /** rank */
+    int rank_;
+    /** trace norm */
+    Type trace_;
+    /** determinant */
+    Type det_;
+
     /// @return the number of rows of U_
     inline int nrowU() const { return U_.sizeRows();}
     /// @return the number of columns of U_
@@ -133,64 +218,33 @@ class ISvd: public IRunnerBase, public IRecursiveTemplate<Derived>
     inline int nrowV() const { return V_.sizeRows();}
     /// @return the number of columns of V_
     inline int ncolV() const { return V_.sizeCols();}
-    /// @return the norm of the matrix
-    inline Real normSup()  const { return norm_;}
-    /// @return the rank of the matrix
-    inline int rank()  const { return rank_;}
-    /// @return U
-    inline ArrayU const& getU() const { return U_;}
-    /// @return  V
-    inline ArrayV const& getV() const { return V_;}
-    /// @return  V
-    inline ArrayVT const& getVT() const { return VT_;}
-    /// @return D
-    inline ArrayD const&  getD() const { return D_;}
-    /** implement the run method */
-    virtual bool run()
-    {
-      if (U_.empty()) { return true;}
-      // compute Svd decomposition
-      if (!this->asDerived().runImpl()) return false;
-      finalize();
-      return true;
-    }
-    /** Compute the svd of the Array A and copy the data
-     *  see the corresponding constructor Take care that if U_ was previously
-     *  a reference, it cannot be modified.
-     *  @param A is the matrix to decompose.
-     *  @param withU if true, we save the left housolder transforms
-     *  in U_.
-     *  @param withV if true, we save the right housolder transforms
-     *  in V_.
-     **/
-    template<class OtherArray>
-    void setData( OtherArray const& A, bool withU = true, bool withV = true)
-    {
-      U_ = A;           // Copy A in U_
-      withU_ = withU;   // copy withU_ value
-      withV_ = withV;   // copy withV_ value
-      V_.resize(0,0), D_.resize(0);
-    }
-
-  protected:
-    /// U_ matrix
-    ArrayU U_;
-    /// V_ matrix
-    ArrayV V_;
-    /// transposed V_
-    ArrayVT VT_;
-    /// Diagonal array of the singular values
-    ArrayD D_;
-    /// Compute U_ ?
-    bool withU_;
-    /// Compute V_ ?
-    bool withV_;
-    /// norm of the matrix (largest singular value)
-    Real norm_;
-    /// rank of the matrix
-    int  rank_;
 };
 
+/* Compute the generalized inverse of the matrix and put the result in res.
+ *  @param res array with the result
+ *  @return the result
+ */
+template<class Derived>
+template<class OtherArray>
+OtherArray& ISvd<Derived>::ginv(OtherArray& res) const
+{
+  Type tol = Arithmetic<Type>::epsilon() * norm_;
+  if(tol==0) { tol = Arithmetic<Type>::epsilon();}
+  // compute D
+  if (U_.cols() != D_.range())
+  {
+    Array2DDiagonal<Real> diag(U_.cols(), 0.0);
+    for (int i= D_.begin(); i< D_.end(); ++i) { diag[i]=D_[i];}
+    res = V_ * diag.safeInverse(tol) * U_.transpose();
+  }
+  else
+  {
+    res = V_ * D_.diagonalize().safeInverse(tol) * U_.transpose();
+  }
+  // compute and return UD^{-1}V'
+  return (res);
+}
+
 } // namespace STK
 
 #endif /* STK_ISVD_H */
