@@ -61,12 +61,12 @@ class IArrayBase: public ArrayBase<Derived>
     typedef typename hidden::Traits<Derived>::Type Type;
     typedef typename hidden::Traits<Derived>::ConstReturnType ConstReturnType;
 
-    typedef typename hidden::Traits<Derived>::Row Row;
-    typedef typename hidden::Traits<Derived>::Col Col;
-    typedef typename hidden::Traits<Derived>::SubRow SubRow;
-    typedef typename hidden::Traits<Derived>::SubCol SubCol;
-    typedef typename hidden::Traits<Derived>::SubVector SubVector;
-    typedef typename hidden::Traits<Derived>::SubArray SubArray;
+    //typedef typename hidden::Traits<Derived>::Row Row;
+    //typedef typename hidden::Traits<Derived>::Col Col;
+    //typedef typename hidden::Traits<Derived>::SubRow SubRow;
+    //typedef typename hidden::Traits<Derived>::SubCol SubCol;
+    //typedef typename hidden::Traits<Derived>::SubVector SubVector;
+//    typedef typename hidden::Traits<Derived>::SubArray SubArray;
 
     enum
     {
@@ -84,66 +84,6 @@ class IArrayBase: public ArrayBase<Derived>
     ~IArrayBase() {}
 
   public:
-    /** @return the jth column of this */
-    inline Col col(int j) const { return this->asDerived().colImpl(j);}
-    /** @return the jth column of this in the range I*/
-    inline SubCol col(Range const& I, int j) const
-    {
-      STK_STATIC_ASSERT_TWO_DIMENSIONS_ONLY(Derived)
-#ifdef STK_BOUNDS_CHECK
-      if (this->beginRows() > I.begin()) { STKOUT_OF_RANGE_2ARG(IArrayBase::col, I, j, beginRows() > I.begin());}
-      if (this->endRows() < I.end())     { STKOUT_OF_RANGE_2ARG(IArrayBase::col, I, j, endRows() < I.end());}
-      if (this->beginCols() > j)         { STKOUT_OF_RANGE_2ARG(IArrayBase::col, I, j, beginCols() > j);}
-      if (this->endCols() <= j)          { STKOUT_OF_RANGE_2ARG(IArrayBase::col, I, j, endCols() <= j);}
-#endif
-      return this->asDerived().colImpl(I, j);
-    }
-    /** @return the sub array with the column in the range J */
-    inline SubArray col(Range const& J) const
-    {
-      STK_STATIC_ASSERT_TWO_DIMENSIONS_ONLY(Derived)
-#ifdef STK_BOUNDS_CHECK
-      if (this->beginCols() > J.begin())
-      { STKOUT_OF_RANGE_1ARG(IArrayBase::col, J, beginCols() > J.begin());}
-      if (this->endCols() < J.end())
-      { STKOUT_OF_RANGE_1ARG(IArrayBase::col, J, endCols() < J.end());}
-#endif
-      return this->asDerived().colImpl(J);
-    }
-    /** @return the ith row of this */
-    inline Row row(int i) const
-    {
-#ifdef STK_BOUNDS_CHECK
-      if (this->beginRows() > i) { STKOUT_OF_RANGE_1ARG(IArrayBase::row, i, beginRows() > i);}
-      if (this->endRows() <= i)  { STKOUT_OF_RANGE_1ARG(IArrayBase::row, i, endRows() <= i);}
-#endif
-      return this->asDerived().rowImpl(i);
-    }
-    /** @return the ith row of this in the range J */
-    inline SubRow row(int i, Range const& J) const
-    {
-      STK_STATIC_ASSERT_TWO_DIMENSIONS_ONLY(Derived)
-      return this->asDerived().rowImpl(i,J);
-    }
-
-    /** @return the sub array with the rows in the range J */
-    inline SubArray row(Range const& I) const
-    {
-      STK_STATIC_ASSERT_TWO_DIMENSIONS_ONLY(Derived)
-      return this->asDerived().rowImpl(I);
-    }
-    /** @return the sub-array (I,J)*/
-    inline SubArray sub(Range const& I, Range const& J) const
-    {
-      STK_STATIC_ASSERT_TWO_DIMENSIONS_ONLY(Derived)
-      return this->asDerived().subImpl(I, J);
-    }
-    /** @return the sub-vector in the range I*/
-    inline SubVector sub(Range const& I) const
-    {
-      STK_STATIC_ASSERT_ONE_DIMENSION_ONLY(Derived)
-      return this->asDerived().subImpl(I);
-    }
 
     // overloaded operators
     /** @return a constant reference on the element (i,j) of the 2D container.
@@ -159,7 +99,7 @@ class IArrayBase: public ArrayBase<Derived>
 #endif
       return this->elt(i,j);}
     /** @return a reference on the element (i,j) of the 2D container.
-     *  @param i, j indexes of the row and of the column
+     *  @param i, j indexes of the element to get
      **/
     inline Type& operator()(int i, int j)
     {
@@ -172,7 +112,7 @@ class IArrayBase: public ArrayBase<Derived>
       return this->elt(i,j);
     }
     /** @return the ith element
-     *  @param i index of the ith element
+     *  @param i index of the element to get
      **/
     inline ConstReturnType operator[](int i) const
     {
@@ -184,7 +124,7 @@ class IArrayBase: public ArrayBase<Derived>
       return this->elt(i);
     }
     /** @return a reference on the ith element
-     *  @param i index of the ith element
+     *  @param i index of the element to get
      **/
     inline Type& operator[](int i)
     {
@@ -205,31 +145,31 @@ class IArrayBase: public ArrayBase<Derived>
     {
       return this->elt();
     }
-    // overloaded operators for sub-arrays/vectors
-    /** @return the sub-vector in given range
-     *  @param I range to get
-     **/
-    inline SubVector operator[](Range const& I) const
-    {
-      STK_STATIC_ASSERT_ONE_DIMENSION_ONLY(Derived);
-      return this->sub(I);
-    }
-    /** @param I range of the index of the rows
-     *  @param j index of the column
-     *  @return a Vertical container containing the column @c j of this
-     *  in the range @c I
-     **/
-    inline SubCol operator()(Range const& I, int j) const { return this->col(I, j);}
-    /** @param i index of the row
-     *  @param J range of the columns
-     *  @return an Horizontal container containing the row @c i of this
-     *  in the range @c J
-     **/
-    inline SubRow operator()(int i, Range const& J) const { return this->row(i, J);}
-    /** @param I,J range of the rows and of the columns
-     *  @return a 2D container containing this in the range @c I, @c J
-     **/
-    inline SubArray operator()(Range const& I, Range const& J) const { return this->sub(I, J);}
+//    // overloaded operators for sub-arrays/vectors
+//    /** @return the sub-vector in given range
+//     *  @param I range to get
+//     **/
+//    inline SubVector operator[](Range const& I) const
+//    {
+//      STK_STATIC_ASSERT_ONE_DIMENSION_ONLY(Derived);
+//      return this->sub(I);
+//    }
+//    /** @param I range of the index of the rows
+//     *  @param j index of the column
+//     *  @return a Vertical container containing the column @c j of this
+//     *  in the range @c I
+//     **/
+//    inline SubCol operator()(Range const& I, int j) const { return this->col(I, j);}
+//    /** @param i index of the row
+//     *  @param J range of the columns
+//     *  @return an Horizontal container containing the row @c i of this
+//     *  in the range @c J
+//     **/
+//    inline SubRow operator()(int i, Range const& J) const { return this->row(i, J);}
+//    /** @param I,J range of the rows and of the columns
+//     *  @return a 2D container containing this in the range @c I, @c J
+//     **/
+//    inline SubArray operator()(Range const& I, Range const& J) const { return this->sub(I, J);}
 };
 
 } // namespace STK
